==> gambas3-debug-3.21.1-1-x86_64.pkg.tar.zst: usr/src/debug/gambas3/gambas-3.21.1/main/gbx/gbx_watch.h <==
/***************************************************************************
  
  gbx_watch.h
  
  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.
  
***************************************************************************/

#ifndef __GBX_WATCH_H
#define __GBX_WATCH_H

#include "gambas.h"
#include <sys/time.h>

#ifdef OS_OPENBSD
#include <signal.h>
#endif

enum {
	WP_NOTHING = 0,
	WP_END = 1,
	WP_OUTPUT = 2,
	WP_ERROR = 4,
	WP_TIMEOUT = 8
};
	
typedef
  struct {
    int fd;
    void (*callback_read)();
    void (*callback_write)();
    intptr_t param_read;
    intptr_t param_write;
    }
  WATCH_CALLBACK;

typedef
	struct {
		GB_TIMER *timer;
		struct timeval timeout;
	}
	WATCH_TIMER;

void WATCH_init(void);
void WATCH_exit(void);
void WATCH_transfer_watch(void);
void WATCH_transfer_timer(void);

void WATCH_watch(int fd, int flag, void *callback, intptr_t param);
bool WATCH_one_loop(int);
void WATCH_loop(void);
void WATCH_wait(int);
int WATCH_loop_signal(const sigset_t *sig);
int WATCH_process(int fd_end, int fd_output, int fd_error, int timeout);
void WATCH_timer(void *t, int on);
double WATCH_get_timeout(GB_TIMER *timer);
void WATCH_little_sleep(void);

#endif /* */

==> gambas3-debug-3.21.3-2-x86_64.pkg.tar.zst: usr/src/debug/gambas3/gambas-3.21.3/main/gbx/gbx_watch.h <==
/***************************************************************************
  
  gbx_watch.h
  
  (c) Benoît Minisini <benoit.minisini@gambas-basic.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2, or (at your option)
  any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA 02110-1301, USA.
  
***************************************************************************/

#ifndef __GBX_WATCH_H
#define __GBX_WATCH_H

#include "gambas.h"
#include <sys/time.h>

#ifdef OS_OPENBSD
#include <signal.h>
#endif

enum {
	WP_NOTHING = 0,
	WP_END = 1,
	WP_OUTPUT = 2,
	WP_ERROR = 4,
	WP_TIMEOUT = 8
};
	
typedef
  struct {
    int fd;
    void (*callback_read)();
    void (*callback_write)();
    intptr_t param_read;
    intptr_t param_write;
    }
  WATCH_CALLBACK;

typedef
	struct {
		GB_TIMER *timer;
		struct timeval timeout;
	}
	WATCH_TIMER;

typedef
	struct {
		double limit;
	}
	WATCH_TIMEOUT;
	
void WATCH_init(void);
void WATCH_exit(void);
void WATCH_transfer_watch(void);
void WATCH_transfer_timer(void);

void WATCH_watch(int fd, int flag, void *callback, intptr_t param);
bool WATCH_one_loop(int);
void WATCH_loop(void);
void WATCH_wait(int);
int WATCH_loop_signal(const sigset_t *sig);
void WATCH_timer(void *t, int on);
double WATCH_get_timeout(GB_TIMER *timer);
void WATCH_little_sleep(void);

void WATCH_timeout(WATCH_TIMEOUT *timeout, int timeout_msec);
int WATCH_process(int fd_end, int fd_output, int fd_error, WATCH_TIMEOUT *timeout);

#endif /* */
